<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login GraphQL for Magento 2 (System)
 */

namespace Amasty\SocialLoginGraphQl\Test\GraphQl;

use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Framework\Exception\AuthenticationException;
use Magento\Integration\Api\CustomerTokenServiceInterface;
use Magento\TestFramework\Helper\Bootstrap;
use Magento\TestFramework\TestCase\GraphQlAbstract;

class AmSocialLoginAccountDataTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'amSocialLoginAccountData';
    public const CUSTOMER = 'new_customer@example.com';
    public const CUSTOMER_PASS = 'Qwert12345';

    /**
     * @var CustomerTokenServiceInterface
     */
    private $customerTokenService;

    /**
     * @var CustomerRepositoryInterface $customerRepository
     */
    private $customerRepository;

    protected function setUp(): void
    {
        $objectManager = Bootstrap::getObjectManager();
        $this->customerRepository = $objectManager->get(CustomerRepositoryInterface::class);
        $this->customerTokenService = $objectManager->get(CustomerTokenServiceInterface::class);
    }

    /**
     * @group amasty_social_login
     *
     * @magentoConfigFixture base_website amsociallogin/general/enabled 1
     * @magentoConfigFixture base_website amsociallogin/google/enabled 1
     * @magentoConfigFixture base_website amsociallogin/facebook/enabled 1
     * @magentoConfigFixture base_website amsociallogin/twitter/enabled 1
     * @magentoConfigFixture base_website amsociallogin/instagram/enabled 1
     * @magentoConfigFixture base_website amsociallogin/linkedin/enabled 1
     * @magentoConfigFixture base_website amsociallogin/amazon/enabled 1
     * @magentoConfigFixture base_website amsociallogin/paypal/enabled 1
     * @magentoConfigFixture base_website amsociallogin/twitch/enabled 1
     *
     * @magentoApiDataFixture Amasty_SocialLoginGraphQl::Test/GraphQl/_files/social_accounts.php
     */
    public function testAmSocialLoginAccountDataTest(): void
    {
        $customer = $this->customerRepository->get(self::CUSTOMER);
        $customerName = $customer->getFirstname() . ' ' . $customer->getLastname();

        $fields = [
            ['name' => $customerName, 'type' => "amazon"],
            ['name' => $customerName, 'type' => "facebook"],
            ['name' => $customerName, 'type' => "google"],
            ['name' => $customerName, 'type' => "instagram"],
            ['name' => $customerName, 'type' => "linkedin"],
            ['name' => $customerName, 'type' => "paypal"],
            ['name' => $customerName, 'type' => "twitch"],
            ['name' => $customerName, 'type' => "twitter"]
        ];

        $query = $this->getQuery();
        $response = $this->graphQlQuery($query, [], '', $this->getHeader());

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $fields);
    }

    /**
     * Returns GraphQl query string
     */
    private function getQuery(): string
    {
        return <<<QUERY
query {
    amSocialLoginAccountData {
        name
        type
    }
}
QUERY;
    }

    /**
     * @param string $userName
     * @param string $password
     *
     * @return string[]
     * @throws AuthenticationException
     */
    private function getHeader(
        string $userName = self::CUSTOMER,
        string $password = self::CUSTOMER_PASS
    ): array {
        $customerToken = $this->customerTokenService->createCustomerAccessToken($userName, $password);
        return ['Authorization' => 'Bearer ' . $customerToken];
    }
}
