<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login GraphQL for Magento 2 (System)
 */

namespace Amasty\SocialLoginGraphQl\Test\GraphQl;

use Magento\TestFramework\TestCase\GraphQlAbstract;

class AmSocialLoginButtonConfigTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'amSocialLoginButtonConfig';

    /**
     * @group amasty_social_login
     *
     * @magentoConfigFixture base_website amsociallogin/general/enabled 1
     * @magentoConfigFixture base_website amsociallogin/google/enabled 1
     * @magentoConfigFixture base_website amsociallogin/google/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/google/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/facebook/enabled 1
     * @magentoConfigFixture base_website amsociallogin/facebook/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/facebook/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/twitter/enabled 1
     * @magentoConfigFixture base_website amsociallogin/twitter/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/twitter/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/instagram/enabled 1
     * @magentoConfigFixture base_website amsociallogin/instagram/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/instagram/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/linkedin/enabled 1
     * @magentoConfigFixture base_website amsociallogin/linkedin/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/linkedin/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/amazon/enabled 1
     * @magentoConfigFixture base_website amsociallogin/amazon/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/amazon/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/paypal/enabled 1
     * @magentoConfigFixture base_website amsociallogin/paypal/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/paypal/api_secret test_graph_api_secret
     * @magentoConfigFixture base_website amsociallogin/twitch/enabled 1
     * @magentoConfigFixture base_website amsociallogin/twitch/api_key test_graph_api_key
     * @magentoConfigFixture base_website amsociallogin/twitch/api_secret test_graph_api_secret
     */
    public function testAmSocialLoginButtonConfig(): void
    {
        $fields = [
            ['label' => 'Google', 'type' => "google"],
            ['label' => 'Facebook', 'type' => "facebook"],
            ['label' => 'Twitter', 'type' => "twitter"],
            ['label' => 'Instagram', 'type' => "instagram"],
            ['label' => 'LinkedIn', 'type' => "linkedin"],
            ['label' => 'Amazon', 'type' => 'amazon'],
            ['label' => 'Paypal', 'type' => "paypal"],
            ['label' => 'TwitchTV', 'type' => "twitch"]
        ];

        $query = $this->getQuery();
        $response = $this->graphQlQuery($query);

        $queryUrls = $this->getQueryWithUrls();
        $responseUrls = $this->graphQlQuery($queryUrls);

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $fields);

        foreach ($responseUrls[self::MAIN_QUERY_KEY] as $responseUrl) {
            $this->assertArrayHasKey('url', $responseUrl);
        }
    }

    /**
     * Returns GraphQl query string
     */
    private function getQuery(): string
    {
        return <<<QUERY
query {
    amSocialLoginButtonConfig {
        label
        type
    }
}
QUERY;
    }

    /**
     * Returns GraphQl query string with all query fields
     */
    private function getQueryWithUrls(): string
    {
        return <<<QUERY
query {
    amSocialLoginButtonConfig {
        label
        type
        url
    }
}
QUERY;
    }
}
