<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login GraphQL for Magento 2 (System)
 */

namespace Amasty\SocialLoginGraphQl\Test\GraphQl;

use Magento\Framework\Exception\AuthenticationException;
use Magento\Integration\Api\CustomerTokenServiceInterface;
use Magento\TestFramework\Helper\Bootstrap;
use Magento\TestFramework\TestCase\GraphQlAbstract;

class AmSocialLoginLinkAccountTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'amSocialLoginLinkAccount';
    public const CUSTOMER = 'new_customer@example.com';
    public const CUSTOMER_PASS = 'Qwert12345';

    /**
     * @var CustomerTokenServiceInterface
     */
    private $customerTokenService;

    protected function setUp(): void
    {
        $objectManager = Bootstrap::getObjectManager();
        $this->customerTokenService = $objectManager->get(CustomerTokenServiceInterface::class);
    }

    /**
     * @group amasty_social_login
     *
     * @magentoConfigFixture base_website amsociallogin/general/enabled 1
     * @magentoConfigFixture base_website amsociallogin/twitter/enabled 1
     *
     * @magentoApiDataFixture Magento/Customer/_files/new_customer.php
     */
    public function testAmSocialLoginLinkAccount(): void
    {
        $query = $this->getQuery('twitter');
        $response = $this->graphQlMutation($query, [], '', $this->getHeader());

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertArrayHasKey('isSuccess', $response[self::MAIN_QUERY_KEY]);
        $this->assertArrayHasKey('message', $response[self::MAIN_QUERY_KEY]);
    }

    /**
     * Returns GraphQl query string
     */
    private function getQuery(string $type): string
    {
        return <<<MUTATION
mutation {
  amSocialLoginLinkAccount (type:"$type") {
    isSuccess
    message
  }
}
MUTATION;
    }

    /**
     * @param string $userName
     * @param string $password
     *
     * @return string[]
     * @throws AuthenticationException
     */
    private function getHeader(
        string $userName = self::CUSTOMER,
        string $password = self::CUSTOMER_PASS
    ): array {
        $customerToken = $this->customerTokenService->createCustomerAccessToken($userName, $password);
        return ['Authorization' => 'Bearer ' . $customerToken];
    }
}
