<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login GraphQL for Magento 2 (System)
 */

namespace Amasty\SocialLoginGraphQl\Test\GraphQl;

use Magento\Framework\Exception\AuthenticationException;
use Magento\Integration\Api\CustomerTokenServiceInterface;
use Magento\TestFramework\Helper\Bootstrap;
use Magento\TestFramework\TestCase\GraphQlAbstract;

class AmSocialLoginUnlinkAccountTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'amSocialLoginUnlinkAccount';
    public const CUSTOMER = 'new_customer@example.com';
    public const CUSTOMER_PASS = 'Qwert12345';

    /**
     * @var CustomerTokenServiceInterface
     */
    private $customerTokenService;

    protected function setUp(): void
    {
        $objectManager = Bootstrap::getObjectManager();
        $this->customerTokenService = $objectManager->get(CustomerTokenServiceInterface::class);
    }

    /**
     * @group amasty_social_login
     *
     * @magentoConfigFixture base_website amsociallogin/general/enabled 1
     * @magentoConfigFixture base_website amsociallogin/google/enabled 1
     *
     * @magentoApiDataFixture Amasty_SocialLoginGraphQl::Test/GraphQl/_files/social_accounts.php
     */
    public function testAmSocialLoginUnlinkAccountLinked(): void
    {
        $fields = [
            'isSuccess' => true,
            'message' => "Your account was successfully unlinked."
        ];

        $query = $this->getQuery('google');
        $response = $this->graphQlMutation($query, [], '', $this->getHeader());

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $fields);
    }

    /**
     * @group amasty_social_login
     *
     * @magentoConfigFixture base_website amsociallogin/general/enabled 1
     * @magentoConfigFixture base_website amsociallogin/google/enabled 1
     *
     * @magentoApiDataFixture Magento/Customer/_files/new_customer.php
     */
    public function testAmSocialLoginUnlinkAccountUnlinked(): void
    {
        $fields = [
            'isSuccess' => false,
            'message' => 'Sorry. We can`t find information about your account.'
        ];

        $query = $this->getQuery('google');
        $response = $this->graphQlMutation($query, [], '', $this->getHeader());

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $fields);
    }

    /**
     * Returns GraphQl query string
     */
    private function getQuery($type): string
    {
        return <<<QUERY
mutation {
    amSocialLoginUnlinkAccount(type: "$type") {
        isSuccess
        message
    }
}
QUERY;
    }

    /**
     * @param string $userName
     * @param string $password
     *
     * @return string[]
     * @throws AuthenticationException
     */
    private function getHeader(
        string $userName = self::CUSTOMER,
        string $password = self::CUSTOMER_PASS
    ): array {
        $customerToken = $this->customerTokenService->createCustomerAccessToken($userName, $password);
        return ['Authorization' => 'Bearer ' . $customerToken];
    }
}
